@@ -106,6 +106,9 @@ private:
 
     void cancelDataDial2 ();
 
+    //! This function will find out the proxy information for the system
+    bool getSystemProxies (QNetworkProxy &http, QNetworkProxy &https);
+
 private:
     bool                    bUseIphoneUA;
 
