@@ -19,8 +19,8 @@
 #define UA_N900   "Mozilla/5.0 (X11; U; Linux armv7l; en-GB; rv:1.9.2a1pre) Gecko/20090928 Firefox/3.5 Maemo Browser 1.4.1.21 RX-51 N900"
 #define UA_IPHONE "Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16"
 
-//#define GV_URL              "http://www.google.com/voice"
-#define GV_URL          "http://m.google.com/voice"
+#define GV_URL              "http://www.google.com/voice"
+//#define GV_URL          "http://m.google.com/voice"
 #define GV_HTTPS        "https://www.google.com/voice"
 #define GV_HTTPS_M      "https://www.google.com/voice/m"
 
